@@ -34,6 +34,7 @@ from sqlalchemy.sql.expression import (
     except_all,
     exists,
     extract,
+    false,
     func,
     insert,
     intersect,
@@ -48,10 +49,12 @@ from sqlalchemy.sql.expression import (
     or_,
     outerjoin,
     outparam,
+    over,
     select,
     subquery,
     table,
     text,
+    true,
     tuple_,
     type_coerce,
     union,
